# autobasedoc
> Automating documentation workflow using matplotlib figures and reportlab.

This package uses reportlab, svglib, matplotlib and pdfrw, and does not provide workflows on that basis, any customization on a specific workflow should be avoided here.
The open-source license of the corresponding packages can be obtained from the python package index.
This package tries to be as small as possible making use of a minimum number of included modules.
The focus of this package is in including matplotlib figures into the reportlab platypus work-flow, pdfrw is used for that purpose.
Large portions are based on Examples of code, that where posted on e.g. stackoverflow and other internet resources, those examples all have been modified respecting the licenses under which they have been released, see LICENSE.md.
The reading and contributing of code and documentation or examples is encouraged, please feel free to fork and request merges...

## Installation

OS X & Linux & Windows:

```sh
pip install autobasedoc
```

## Usage example

_For examples and usage, please go to the [Wiki][wiki]._

## Documentation

http://autobasedoc.readthedocs.io/

## Meta

Twitter – [@eckjoh2](https://twitter.com/eckjoh2) – contact@nucos.de

See ``LICENSE`` for more information.

[https://github.com/NuCOS](https://github.com/NuCOS)

## Contributing

1. Fork it (<https://github.com/yourname/yourproject/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request

## Testing

under linux there is a genie.sh test runner.
you can start tests with nose2

<!-- Markdown link & img dfn's -->
[wiki]: https://github.com/NuCOS/autobasedoc/wiki
